import { Button } from '@material-ui/core'
import defaultIcon from 'assets/icons/visu/duel/default.svg'
import EcogestureModal from 'components/Ecogesture/EcogestureModal'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { defaultEcogestureData } from '../../../tests/__mocks__/actionData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { profileData } from '../../../tests/__mocks__/profileData.mock'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import ActionCard from './ActionCard'

const mockStore = configureStore([])

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockImportIconById = jest.fn(() => defaultIcon)
jest.mock('utils/utils', () => {
  return {
    importIconById: jest.fn(() => {
      return mockImportIconById
    }),
  }
})
describe('ActionCard component', () => {
  it('should be rendered correctly', async () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionCard
          setShowList={jest.fn()}
          setSelectedAction={jest.fn()}
          action={defaultEcogestureData[1]}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should open modal', () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionCard
          setShowList={jest.fn()}
          setSelectedAction={jest.fn()}
          action={defaultEcogestureData[1]}
        />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    expect(wrapper.find(EcogestureModal).exists()).toBeTruthy()
  })
})
