import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import * as reactRedux from 'react-redux'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import UsageEventService from 'services/usageEvent.service'
import * as challengeActions from 'store/challenge/challenge.slice'
import { defaultEcogestureData } from '../../../tests/__mocks__/actionData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { profileData } from '../../../tests/__mocks__/profileData.mock'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import ActionModal from './ActionModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockupdateUserChallenge = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => {
    return {
      updateUserChallenge: mockupdateUserChallenge,
    }
  })
})
jest.mock('services/usageEvent.service')
const mockAddEvent = jest.fn()
UsageEventService.addEvent = mockAddEvent
const mockStore = configureStore([])

describe('ActionModal component', () => {
  it('should render correctly', async () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionModal
          open={true}
          handleCloseClick={jest.fn()}
          action={defaultEcogestureData[1]}
          userChallenge={userChallengeData[1]}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should click on button and update action to ongoing', async () => {
    const useDispatchSpy = jest.spyOn(reactRedux, 'useDispatch')
    const updateChallengeSpy = jest.spyOn(
      challengeActions,
      'updateUserChallengeList'
    )

    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    mockupdateUserChallenge.mockResolvedValueOnce(userChallengeData[1])
    useDispatchSpy.mockReturnValue(jest.fn())

    const wrapper = mount(
      <Provider store={store}>
        <ActionModal
          open={true}
          handleCloseClick={jest.fn()}
          action={defaultEcogestureData[1]}
          userChallenge={userChallengeData[1]}
        />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(updateChallengeSpy).toBeCalledTimes(1)
  })
})
