import { FluidType } from 'enum/fluid.enum'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { graphData } from '../../../tests/__mocks__/chartData.mock'
import mockClient from '../../../tests/__mocks__/client'
import { mockAnalysisState } from '../../../tests/__mocks__/store'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import MaxConsumptionCard from './MaxConsumptionCard'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockGetMaxLoad = jest.fn(() => 0)
const mockGetGraphData = jest.fn(() => graphData)
jest.mock('services/consumption.service', () => {
  return jest.fn(() => {
    return {
      getMaxLoad: mockGetMaxLoad,
      getGraphData: mockGetGraphData,
    }
  })
})
jest.mock('cozy-client', () => {
  return {
    useClient: jest.fn(() => {
      return mockClient
    }),
  }
})

jest.mock('components/Charts/BarChart', () => 'mock-BarChart')

const mockStore = configureStore([])

describe('MaxConsumptionCard component', () => {
  it('should be rendered correctly', async () => {
    const store = mockStore({
      ecolyo: {
        global: {
          fluidTypes: [FluidType.ELECTRICITY, FluidType.GAS],
        },
        analysis: mockAnalysisState,
      },
    })

    const wrapper = mount(
      <Provider store={store}>
        <MaxConsumptionCard />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
    expect(wrapper.find('mock-BarChart').exists()).toBeTruthy()
  })
  it('should be rendered with one fluid and not display arrows', async () => {
    const store = mockStore({
      ecolyo: {
        global: { fluidTypes: [FluidType.ELECTRICITY] },
        analysis: mockAnalysisState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <MaxConsumptionCard />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.arrow').exists()).toBeFalsy()
  })
  it('should be rendered with several fluids and click navigate between fluid', async () => {
    const store = mockStore({
      ecolyo: {
        global: { fluidTypes: [FluidType.ELECTRICITY, FluidType.GAS] },
        analysis: mockAnalysisState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <MaxConsumptionCard />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.arrow-next').exists()).toBeTruthy()
    // navigate next
    wrapper.find('.arrow-next').first().simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.fluid').text()).toBe('FLUID.GAS.LABEL')
    wrapper.find('.arrow-next').first().simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.fluid').text()).toBe('FLUID.ELECTRICITY.LABEL')
    // navigate prev
    wrapper.find('.arrow-prev').first().simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.fluid').text()).toBe('FLUID.GAS.LABEL')
    wrapper.find('.arrow-prev').first().simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.fluid').text()).toBe('FLUID.ELECTRICITY.LABEL')
  })
})
