import MonthlyAnalysis from 'components/Analysis/MonthlyAnalysis'
import { FluidType } from 'enum/fluid.enum'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import { BrowserRouter } from 'react-router-dom'
import configureStore from 'redux-mock-store'
import { mockAnalysisState } from '../../../tests/__mocks__/store'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
jest.mock('services/consumption.service')
jest.mock('components/Analysis/ComparisonView', () => 'mock-comparison-view')
jest.mock('components/Analysis/AnalysisConsumption', () => 'mock-analysis')

const mockStore = configureStore([])

describe('MonthlyAnalysis component', () => {
  it('should be rendered correctly', async () => {
    const store = mockStore({
      ecolyo: {
        global: { fluidTypes: [FluidType.ELECTRICITY, FluidType.GAS] },
        analysis: mockAnalysisState,
      },
    })
    const wrapper = mount(
      <BrowserRouter>
        <Provider store={store}>
          <MonthlyAnalysis
            saveLastScrollPosition={jest.fn()}
            scrollPosition={0}
          />
        </Provider>
      </BrowserRouter>
    ).getElement()
    expect(wrapper).toMatchSnapshot()
  })
})
