import { DataloadState } from 'enum/dataload.enum'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import { DateTime } from 'luxon'
import { DataloadValueDetail } from 'models'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import PieChart from './PieChart'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockGetAllLastPrices = jest.fn()
jest.mock('services/fluidsPrices.service', () => {
  return jest.fn(() => {
    return {
      getAllLastPrices: mockGetAllLastPrices,
    }
  })
})

const mockStore = configureStore([])

describe('PieChart component', () => {
  const mockDataloadValueDetailArray: DataloadValueDetail[] = [
    { value: 10, state: DataloadState.VALID },
    { value: 20, state: DataloadState.VALID },
    { value: 30, state: DataloadState.VALID },
  ]
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <PieChart
          width={300}
          height={300}
          outerRadius={300}
          innerRadius={300}
          currentAnalysisDate={DateTime.fromISO('2021-07-01T00:00:00.000Z', {
            zone: 'utc',
          })}
          totalValue={60}
          dataloadValueDetailArray={mockDataloadValueDetailArray}
        />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should open estimation modal', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <PieChart
          width={300}
          height={300}
          outerRadius={300}
          innerRadius={300}
          currentAnalysisDate={DateTime.fromISO('2021-07-01T00:00:00.000Z', {
            zone: 'utc',
          })}
          totalValue={60}
          dataloadValueDetailArray={mockDataloadValueDetailArray}
        />
      </Provider>
    )
    expect(wrapper.find('.estimation-text').simulate('click'))
  })
})
