import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { mockInitialEcolyoState } from '../../../tests/__mocks__/store'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import EstimatedConsumptionModal from './EstimatedConsumptionModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockGetAllLastPrices = jest.fn()
jest.mock('services/fluidsPrices.service', () => {
  return jest.fn(() => {
    return {
      getAllLastPrices: mockGetAllLastPrices,
    }
  })
})

const mockStore = configureStore([])
const mockHandleClose = jest.fn()
describe('EstimatedConsumptionModal component', () => {
  it('should render correctly', async () => {
    const store = mockStore({
      ecolyo: mockInitialEcolyoState,
    })
    const wrapper = mount(
      <Provider store={store}>
        <EstimatedConsumptionModal
          open={true}
          handleCloseClick={mockHandleClose}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
})
