import { IconButton } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import { DateTime } from 'luxon'
import React from 'react'
import * as reactRedux from 'react-redux'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { mockInitialChartState } from '../../../tests/__mocks__/store'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import DateNavigator from './DateNavigator'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockStore = configureStore([])

jest.mock(
  'components/DateNavigator/DateNavigatorFormat',
  () => 'mock-date-navigator-format'
)

const mockUseDispatch = jest.spyOn(reactRedux, 'useDispatch')

describe('DateNavigator component', () => {
  const mockedDate = DateTime.local(2021, 7, 1)
    .setZone('utc', {
      keepLocalTime: true,
    })
    .startOf('day')
  it('should be rendered correctly', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        chart: mockInitialChartState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <DateNavigator currentAnalysisDate={mockedDate} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should click on left arrow and change date', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        chart: mockInitialChartState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <DateNavigator currentAnalysisDate={mockedDate} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find(IconButton).first().simulate('click')
    expect(mockUseDispatch).toHaveBeenCalledTimes(2)
  })
  it('should click on right arrow and change date', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        chart: mockInitialChartState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <DateNavigator currentAnalysisDate={mockedDate} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find(IconButton).at(1).simulate('click')
    expect(mockUseDispatch).toHaveBeenCalledTimes(3)
  })

  it('should be rendered without analysis date and change to previous index', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        chart: mockInitialChartState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <DateNavigator />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find(IconButton).at(0).simulate('click')
    expect(mockUseDispatch).toHaveBeenCalledTimes(4)
  })
  it('should be rendered without analysis date and change to next index', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        chart: mockInitialChartState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <DateNavigator />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find(IconButton).at(1).simulate('click')
    expect(mockUseDispatch).toHaveBeenCalledTimes(5)
  })
})
