/* eslint-disable react/display-name */
import EcogestureCard from 'components/Ecogesture/EcogestureCard'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import { BrowserRouter } from 'react-router-dom'
import configureStore from 'redux-mock-store'
import { mockedEcogesturesData } from '../../../tests/__mocks__/ecogesturesData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
jest.mock('components/CommonKit/Icon/StyledIcon', () => () => (
  <div id="StyledIcon" />
))
const mockImportIconById = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconById: jest.fn(() => {
      return mockImportIconById
    }),
  }
})

const mockStore = configureStore([])

describe('EcogestureCard component', () => {
  it('should be rendered correctly', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    mockImportIconById.mockReturnValueOnce('')
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <EcogestureCard ecogesture={mockedEcogesturesData[0]} />
        </BrowserRouter>
      </Provider>
    )
    await waitForComponentToPaint(wrapper)

    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should be with default icon', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    mockImportIconById.mockReturnValue(undefined)
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <EcogestureCard ecogesture={mockedEcogesturesData[0]} />
        </BrowserRouter>
      </Provider>
    )
    await waitForComponentToPaint(wrapper)

    expect(wrapper.find('.Icon').exists()).toBeTruthy()
  })
})
