/* eslint-disable react/display-name */
import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import * as reactRedux from 'react-redux'
import { Provider } from 'react-redux'
import {
  mockEcogestureAnswer,
  mockProfileEcogesture,
} from '../../../tests/__mocks__/profileEcogesture.mock'
import { createMockEcolyoStore } from '../../../tests/__mocks__/store'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import EcogestureFormSingleChoice from './EcogestureFormSingleChoice'

const useSelectorSpy = jest.spyOn(reactRedux, 'useSelector')

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

jest.mock(
  'components/EcogestureForm/EcogestureLaunchFormModal',
  () => 'mock-ecogesturelaunchmodal'
)

const mockHandleNextStep = jest.fn()
const mockHandlePreviousStep = jest.fn()
describe('EcogestureFormSingleChoice component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    store.clearActions()
  })

  it('should be rendered correctly', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormSingleChoice
          step={0}
          viewedStep={1}
          setNextStep={mockHandleNextStep}
          setPreviousStep={mockHandlePreviousStep}
          currentProfileEcogesture={mockProfileEcogesture}
          answerType={mockEcogestureAnswer}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should click on disabled button', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormSingleChoice
          step={0}
          viewedStep={1}
          setNextStep={mockHandleNextStep}
          setPreviousStep={mockHandlePreviousStep}
          currentProfileEcogesture={mockProfileEcogesture}
          answerType={mockEcogestureAnswer}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find(Button).first().simulate('click')
    expect(mockHandlePreviousStep).toHaveBeenCalledTimes(0)
  })

  it('should pick a choice and go next', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormSingleChoice
          step={0}
          viewedStep={1}
          setNextStep={mockHandleNextStep}
          setPreviousStep={mockHandlePreviousStep}
          currentProfileEcogesture={mockProfileEcogesture}
          answerType={mockEcogestureAnswer}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find('input').first().simulate('change')
    await waitForComponentToPaint(wrapper)
    wrapper.find(Button).at(1).simulate('click')

    expect(mockHandleNextStep).toHaveBeenCalledTimes(1)
  })
  it('should go back', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormSingleChoice
          step={1}
          viewedStep={0}
          setNextStep={mockHandleNextStep}
          setPreviousStep={mockHandlePreviousStep}
          currentProfileEcogesture={mockProfileEcogesture}
          answerType={mockEcogestureAnswer}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find(Button).first().simulate('click')
    expect(mockHandlePreviousStep).toHaveBeenCalledTimes(1)
  })
  it('should keep previous answer', async () => {
    useSelectorSpy.mockReturnValue({
      profile: {
        isProfileEcogestureCompleted: true,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormSingleChoice
          step={0}
          viewedStep={1}
          setNextStep={mockHandleNextStep}
          setPreviousStep={mockHandlePreviousStep}
          currentProfileEcogesture={mockProfileEcogesture}
          answerType={mockEcogestureAnswer}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('input').first().hasClass('checked-input')).toBe(true)
  })
})
