import classNames from 'classnames'
import FormNavigation from 'components/FormGlobal/FormNavigation'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { EcogestureStepForm } from 'enum/ecogestureForm.enum'
import {
  ProfileEcogesture,
  ProfileEcogestureAnswer,
  ProfileEcogestureValues,
} from 'models/profileEcogesture.model'
import React, { useCallback, useState } from 'react'
import { useSelector } from 'react-redux'
import { AppStore } from 'store'
import './ecogestureFormSingleChoice.scss'
interface EcogestureFormSingleChoiceProps {
  step: EcogestureStepForm
  viewedStep: EcogestureStepForm
  currentProfileEcogesture: ProfileEcogesture
  answerType: ProfileEcogestureAnswer
  setNextStep: (_profileEcogesture: ProfileEcogesture) => void
  setPreviousStep: () => void
}

const EcogestureFormSingleChoice = ({
  step,
  viewedStep,
  currentProfileEcogesture,
  answerType,
  setNextStep,
  setPreviousStep,
}: EcogestureFormSingleChoiceProps) => {
  const { t } = useI18n()
  const { isProfileEcogestureCompleted } = useSelector(
    (state: AppStore) => state.ecolyo.profile
  )
  const [answer, setAnswer] = useState<ProfileEcogestureValues>(
    isProfileEcogestureCompleted || step < viewedStep
      ? currentProfileEcogesture[answerType.attribute]
      : null
  )

  const handlePrevious = useCallback(() => {
    setPreviousStep()
  }, [setPreviousStep])

  const handleNext = useCallback(() => {
    setNextStep({ ...currentProfileEcogesture, [answerType.attribute]: answer })
  }, [currentProfileEcogesture, setNextStep, answer, answerType.attribute])

  return (
    <div className="ecogesture-profile-container">
      <div className={'profile-form-container ecogesture-form-single'}>
        <div className={'profile-question-label'}>
          {t(
            `ecogesture_form.${EcogestureStepForm[step].toLowerCase()}.question`
          )}
        </div>
        {answerType.choices.map(value => {
          if (!value) return null
          return (
            <label
              key={value.toString()}
              className={classNames({
                ['radio_short']: answerType.choices.length < 5,
                ['radio_long']: answerType.choices.length > 4,
                ['answer-checked']: answer === value,
              })}
            >
              <input
                type={'radio'}
                value={value}
                name={value.toString()}
                onChange={() => setAnswer(value)}
                checked={answer === value}
                className={answer === value ? 'checked-input' : ''}
              />
              {t(
                `ecogesture_form.${EcogestureStepForm[
                  step
                ].toLowerCase()}.${value}`
              )}
            </label>
          )
        })}
      </div>
      <FormNavigation
        step={step}
        handlePrevious={handlePrevious}
        handleNext={handleNext}
        disableNextButton={answer === null}
        isEcogesture={true}
      />
    </div>
  )
}

export default EcogestureFormSingleChoice
