import Content from 'components/Content/Content'
import EcogestureFormEquipment from 'components/EcogestureForm/EcogestureFormEquipment'
import EcogestureFormSingleChoice from 'components/EcogestureForm/EcogestureFormSingleChoice'
import EcogestureLaunchFormModal from 'components/EcogestureForm/EcogestureLaunchFormModal'
import CozyBar from 'components/Header/CozyBar'
import Header from 'components/Header/Header'
import Loader from 'components/Loader/Loader'
import ProfileTypeView from 'components/ProfileType/ProfileTypeView'
import {
  EcogestureStepForm,
  ProfileEcogestureAnswerType,
} from 'enum/ecogestureForm.enum'
import {
  ProfileEcogesture,
  ProfileEcogestureAnswer,
} from 'models/profileEcogesture.model'
import React, { Dispatch, useCallback, useEffect, useState } from 'react'
import { useDispatch, useSelector } from 'react-redux'
import { useLocation, useNavigate } from 'react-router-dom'
import ProfileEcogestureFormService from 'services/profileEcogestureForm.service'
import { AppActionsTypes, AppStore } from 'store'
import { updateProfile } from 'store/profile/profile.actions'
import { newProfileEcogestureEntry } from 'store/profileEcogesture/profileEcogesture.actions'

const EcogestureFormView = () => {
  const dispatch: Dispatch<AppActionsTypes> = useDispatch()
  const {
    profile: { isProfileTypeCompleted },
    profileEcogesture,
  } = useSelector((state: AppStore) => state.ecolyo)
  const navigate = useNavigate()
  const [headerHeight, setHeaderHeight] = useState<number>(0)
  const defineHeaderHeight = (height: number) => {
    setHeaderHeight(height)
  }

  const shouldOpenModal = new URLSearchParams(useLocation().search).get('modal')
  const [step, setStep] = useState<EcogestureStepForm>(
    EcogestureStepForm.HEATING_TYPE
  )
  const [answerType, setAnswerType] = useState<ProfileEcogestureAnswer>({
    type: ProfileEcogestureAnswerType.SINGLE_CHOICE,
    attribute: 'heating',
    choices: [],
  })

  const [isLoading, setIsLoading] = useState<boolean>(true)
  const [openLaunchModal, setOpenLaunchModal] = useState<boolean>(
    shouldOpenModal !== 'false' ? true : false
  )
  const [viewedStep, setViewedStep] = useState<number>(-1)
  const [currentProfileEcogesture, setCurrentProfileEcogesture] =
    useState<ProfileEcogesture>(profileEcogesture)
  const setNextStep = useCallback(
    (_profileEcogesture: ProfileEcogesture) => {
      setCurrentProfileEcogesture(_profileEcogesture)
      const pefs = new ProfileEcogestureFormService(_profileEcogesture)
      const nextStep = pefs.getNextFormStep(step)
      setIsLoading(true)
      if (nextStep > viewedStep) {
        setViewedStep(nextStep)
      }
      const _answerType =
        ProfileEcogestureFormService.getAnswerForStep(nextStep)
      setAnswerType(_answerType)
      setStep(nextStep)
    },
    [step, viewedStep]
  )
  const setPreviousStep = useCallback(() => {
    const pefs = new ProfileEcogestureFormService(currentProfileEcogesture)
    const previousStep = pefs.getPreviousFormStep(step)
    setIsLoading(true)
    const _answerType =
      ProfileEcogestureFormService.getAnswerForStep(previousStep)
    setAnswerType(_answerType)
    setStep(previousStep)
  }, [currentProfileEcogesture, step])

  const handleEndForm = useCallback(() => {
    dispatch(newProfileEcogestureEntry(currentProfileEcogesture))
    dispatch(updateProfile({ isProfileEcogestureCompleted: true }))
    navigate('/ecogesture-selection')
  }, [currentProfileEcogesture, dispatch, navigate])

  useEffect(() => {
    const _answerType = ProfileEcogestureFormService.getAnswerForStep(step)
    setAnswerType(_answerType)
    setIsLoading(false)

    // handle end of form
    if (step === EcogestureStepForm.END) {
      handleEndForm()
    }
  }, [handleEndForm, step])

  if (isLoading) {
    return (
      <Content height={headerHeight}>
        <Loader />
      </Content>
    )
  }
  return (
    <>
      <CozyBar titleKey={'common.title_ecogestures'} />
      <Header
        setHeaderHeight={defineHeaderHeight}
        desktopTitleKey={'common.title_ecogestures'}
      />
      <Content height={headerHeight}>
        {isProfileTypeCompleted ? (
          <ProfileTypeView />
        ) : (
          <>
            {step === EcogestureStepForm.EQUIPMENTS && (
              <EcogestureFormEquipment
                step={EcogestureStepForm.EQUIPMENTS}
                currentProfileEcogesture={currentProfileEcogesture}
                setNextStepEcogestureForm={setNextStep}
                setPreviousStep={setPreviousStep}
              />
            )}
            {step !== EcogestureStepForm.EQUIPMENTS && (
              <EcogestureFormSingleChoice
                step={step}
                viewedStep={viewedStep}
                currentProfileEcogesture={currentProfileEcogesture}
                answerType={answerType}
                setNextStep={setNextStep}
                setPreviousStep={setPreviousStep}
              />
            )}
          </>
        )}
      </Content>
      <EcogestureLaunchFormModal
        open={openLaunchModal}
        handleCloseClick={() => setOpenLaunchModal(false)}
      />
    </>
  )
}

export default EcogestureFormView
