import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { mockedEcogesturesData } from '../../../tests/__mocks__/ecogesturesData.mock'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import EcogestureSelectionDetail from './EcogestureSelectionDetail'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockImportIconById = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconById: jest.fn(() => {
      return mockImportIconById
    }),
  }
})
const mockValidate = jest.fn()

describe('EcogestureSelectionDetail component', () => {
  beforeEach(() => {
    mockImportIconById.mockClear()
    mockValidate.mockClear()
  })

  it('should be rendered correctly', async () => {
    mockImportIconById.mockReturnValueOnce('testIcon')
    const wrapper = mount(
      <EcogestureSelectionDetail
        ecogesture={mockedEcogesturesData[0]}
        validate={mockValidate}
        title={mockedEcogesturesData[0].shortName}
      />
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should call validate with objective to true', async () => {
    mockImportIconById.mockReturnValueOnce('testIcon')
    const wrapper = mount(
      <EcogestureSelectionDetail
        ecogesture={mockedEcogesturesData[0]}
        validate={mockValidate}
        title={mockedEcogesturesData[0].shortName}
      />
    )
    wrapper.find(Button).at(0).simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(mockValidate).toHaveBeenCalledWith(true, false)
  })

  it('should call validate with doing to true', async () => {
    mockImportIconById.mockReturnValueOnce('testIcon')
    const wrapper = mount(
      <EcogestureSelectionDetail
        ecogesture={mockedEcogesturesData[0]}
        validate={mockValidate}
        title={mockedEcogesturesData[0].shortName}
      />
    )
    wrapper.find(Button).at(1).simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(mockValidate).toHaveBeenCalledWith(false, true)
  })

  it('should call validate with objective and doing to false', async () => {
    mockImportIconById.mockReturnValueOnce('testIcon')
    const wrapper = mount(
      <EcogestureSelectionDetail
        ecogesture={mockedEcogesturesData[0]}
        validate={mockValidate}
        title={mockedEcogesturesData[0].shortName}
      />
    )
    wrapper.find(Button).at(2).simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(mockValidate).toHaveBeenCalledWith(false, false)
  })
})
