import StyledCard from 'components/CommonKit/Card/StyledCard'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import { FluidType } from 'enum/fluid.enum'
import { FluidStatus } from 'models'
import React, { useCallback } from 'react'
import { useSelector } from 'react-redux'
import { useNavigate } from 'react-router-dom'
import { AppStore } from 'store'
import { getAddPicto } from 'utils/picto'
import { getFluidName } from 'utils/utils'
import './konnectorViewerList.scss'

const KonnectorViewerList = () => {
  const { t } = useI18n()
  const { fluidStatus } = useSelector((state: AppStore) => state.ecolyo.global)
  const navigate = useNavigate()
  const goToFluid = useCallback(
    fluidType => {
      navigate(`/consumption/${getFluidName(fluidType)}`)
    },
    [navigate]
  )
  return (
    <>
      {fluidStatus.map((fluidStatusItem: FluidStatus, key: number) => (
        <StyledCard
          key={key}
          className="connection-card"
          onClick={() => goToFluid(fluidStatusItem.fluidType)}
          fluidType={fluidStatusItem.fluidType}
        >
          <Icon icon={getAddPicto(fluidStatusItem.fluidType)} size={36} />
          <div
            className={`konnector-title text-18-bold ${FluidType[
              fluidStatusItem.fluidType
            ].toLowerCase()}`}
          >
            {t(
              `konnector_options.label_connect_to_${FluidType[
                fluidStatusItem.fluidType
              ].toLowerCase()}`
            )}
          </div>
        </StyledCard>
      ))}
    </>
  )
}

export default KonnectorViewerList
