import { Button } from '@material-ui/core'
import StyledSwitch from 'components/CommonKit/Switch/StyledSwitch'
import ReportOptions from 'components/Options/ReportOptions/ReportOptions'
import { FluidState, FluidType } from 'enum/fluid.enum'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import * as profileActions from 'store/profile/profile.actions'
import {
  createMockEcolyoStore,
  mockInitialEcolyoState,
} from '../../../../tests/__mocks__/store'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockUpdateProfile = jest.fn()
jest.mock('services/profile.service', () => {
  return jest.fn(() => {
    return {
      updateProfile: mockUpdateProfile,
    }
  })
})

const updateProfileSpy = jest.spyOn(profileActions, 'updateProfile')

describe('ReportOptions component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    store.clearActions()
    updateProfileSpy.mockClear()
  })

  it('should be rendered with sendAnalysisNotification to true', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ReportOptions />
      </Provider>
    )
    expect(wrapper.find(Button).text()).toBe('profile.report.deactivate')
  })

  it('should update the profile with sendAnalysisNotification to false', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ReportOptions />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    expect(updateProfileSpy).toBeCalledTimes(1)
    expect(updateProfileSpy).toHaveBeenCalledWith({
      sendAnalysisNotification: false,
    })
  })
  it('should be rendered with sendAnalysisNotification false and toggle it to true', () => {
    mockInitialEcolyoState.profile.sendAnalysisNotification = false

    const wrapper = mount(
      <Provider store={store}>
        <ReportOptions />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    expect(updateProfileSpy).toBeCalledTimes(1)
    expect(updateProfileSpy).toHaveBeenCalledWith({
      sendAnalysisNotification: true,
    })
  })

  it('should be rendered with sendConsumptionAlert to false', () => {
    mockInitialEcolyoState.profile.sendAnalysisNotification = false
    mockInitialEcolyoState.global.fluidStatus[FluidType.WATER].status =
      FluidState.DONE
    const wrapper = mount(
      <Provider store={store}>
        <ReportOptions />
      </Provider>
    )
    expect(wrapper.find(StyledSwitch)).toHaveLength(1)
    expect(wrapper.find(StyledSwitch).first().props().checked).toBeFalsy()
  })

  it('should update the profile with sendConsumptionAlert to true', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ReportOptions />
      </Provider>
    )
    wrapper
      .find('input')
      .first()
      .simulate('change', { target: { checked: 'true' } })
    expect(updateProfileSpy).toBeCalledTimes(1)
    expect(updateProfileSpy).toHaveBeenCalledWith({
      sendConsumptionAlert: true,
    })
  })
})
