import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { mockInitialEcolyoState } from '../../../tests/__mocks__/store'
import PartnerIssueModal from './PartnerIssueModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockStore = configureStore([])
const mockHandleClose = jest.fn()
describe('PartnerIssueModal component', () => {
  const store = mockStore({
    ecolyo: mockInitialEcolyoState,
  })
  it('should render correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <PartnerIssueModal
          open={true}
          handleCloseClick={mockHandleClose}
          issuedFluid={mockInitialEcolyoState.global.fluidStatus[0]}
        />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should render elec modal', () => {
    const wrapper = mount(
      <Provider store={store}>
        <PartnerIssueModal
          open={true}
          handleCloseClick={mockHandleClose}
          issuedFluid={mockInitialEcolyoState.global.fluidStatus[0]}
        />
      </Provider>
    )
    expect(wrapper.text().includes('error_connect_elec')).toBeTruthy()
  })
  it('should render water modal', () => {
    const wrapper = mount(
      <Provider store={store}>
        <PartnerIssueModal
          open={true}
          handleCloseClick={mockHandleClose}
          issuedFluid={mockInitialEcolyoState.global.fluidStatus[1]}
        />
      </Provider>
    )
    expect(wrapper.text().includes('error_connect_water')).toBeTruthy()
  })
  it('should close modal', () => {
    const wrapper = mount(
      <Provider store={store}>
        <PartnerIssueModal
          open={true}
          handleCloseClick={mockHandleClose}
          issuedFluid={mockInitialEcolyoState.global.fluidStatus[0]}
        />
      </Provider>
    )
    wrapper.find(Button).simulate('click')
    expect(mockHandleClose).toHaveBeenCalled()
  })

  it('should not be rendered', () => {
    const wrapper = mount(
      <Provider store={store}>
        <PartnerIssueModal
          open={false}
          handleCloseClick={mockHandleClose}
          issuedFluid={mockInitialEcolyoState.global.fluidStatus[0]}
        />
      </Provider>
    )
    expect(wrapper.find('div.partnerIssueModal').exists()).toBeFalsy()
  })
})
