import QuizCustomQuestionContent from 'components/Quiz/QuizCustomQuestionContent'
import QuizQuestionContent from 'components/Quiz/QuizQuestionContent'
import { Client, useClient } from 'cozy-client'
import { QuestionEntity, UserChallenge } from 'models'
import React, { useEffect, useState } from 'react'
import { useSelector } from 'react-redux'
import { useNavigate } from 'react-router-dom'
import QuizService from 'services/quiz.service'
import { AppStore } from 'store'
import './quizQuestion.scss'

const QuizQuestion = ({ userChallenge }: { userChallenge: UserChallenge }) => {
  const questionsIsLocked: boolean = userChallenge.quiz.questions.some(
    answer => answer.result == 0
  )
  const [question, setQuestion] = useState<QuestionEntity>()
  const [isCustomQuest, setIsCustomQuest] = useState<boolean>(
    !questionsIsLocked
  )
  const [customQuestionLoading, setCustomQuestionLoading] =
    useState<boolean>(false)
  const client: Client = useClient()
  const { fluidTypes } = useSelector((state: AppStore) => state.ecolyo.global)
  const navigate = useNavigate()

  const goBack = () => {
    navigate('/challenges')
  }

  useEffect(() => {
    let subscribed = true
    async function loadCustomQuestion() {
      const quizService: QuizService = new QuizService(client)
      const customQuestion: QuestionEntity =
        await quizService.getCustomQuestion(
          userChallenge.quiz.customQuestion,
          fluidTypes
        )
      if (subscribed) {
        setQuestion(customQuestion)
        setCustomQuestionLoading(false)
      }
    }
    if (isCustomQuest) {
      setCustomQuestionLoading(true)
      loadCustomQuestion()
    }
    return () => {
      subscribed = false
    }
  }, [client, fluidTypes, isCustomQuest, userChallenge.quiz.customQuestion])

  return (
    <>
      {isCustomQuest ? (
        <QuizCustomQuestionContent
          userChallenge={userChallenge}
          goBack={goBack}
          question={question}
          isLoading={customQuestionLoading}
        />
      ) : (
        <QuizQuestionContent
          userChallenge={userChallenge}
          setIsCustomQuest={setIsCustomQuest}
          goBack={goBack}
        />
      )}
    </>
  )
}

export default QuizQuestion
