import QuizQuestionContent from 'components/Quiz/QuizQuestionContent'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

const mockUpdateUserQuiz = jest.fn()
jest.mock('services/quiz.service', () => {
  return jest.fn(() => {
    return {
      updateUserQuiz: mockUpdateUserQuiz,
    }
  })
})

const mockUserChallengeUpdateFlag = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => {
    return {
      updateUserChallenge: mockUserChallengeUpdateFlag,
    }
  })
})

const mockStore = configureStore([])

describe('QuizQuestionContent component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <QuizQuestionContent
          userChallenge={userChallengeData[0]}
          setIsCustomQuest={() => false}
          goBack={mockedNavigate('/challenges')}
        />
      </Provider>
    )
    expect(wrapper.find('.question').text()).toEqual(
      userChallengeData[0].quiz.questions[0].questionLabel
    )
    expect(wrapper.find('input')).toHaveLength(3)
  })
  it('should redirect to challenge on click on btn-back', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <QuizQuestionContent
          userChallenge={userChallengeData[0]}
          setIsCustomQuest={() => false}
          goBack={mockedNavigate('/challenges')}
        />
      </Provider>
    )

    wrapper.find('.btn-back').first().simulate('click')
    expect(mockedNavigate).toHaveBeenCalledWith('/challenges')
  })
})
