import { TimeStep } from 'enum/timeStep.enum'
import { DateTime } from 'luxon'
import { graphData } from '../../../tests/__mocks__/chartData.mock'
import { mockInitialChartState } from '../../../tests/__mocks__/store'
import {
  chartSlice,
  setCurrentDataChart,
  setCurrentDataChartIndex,
  setCurrentIndex,
  setCurrentTimeStep,
  setLoading,
  setSelectedDate,
  setShowCompare,
} from './chart.slice'

describe('chart reducer', () => {
  it('should return the initial state', () => {
    const initialState = chartSlice.reducer(undefined, { type: undefined })
    expect(initialState).toEqual(mockInitialChartState)
  })

  it('should return same state if no action', () => {
    const state = chartSlice.reducer(mockInitialChartState, { type: undefined })
    expect(state).toEqual(mockInitialChartState)
  })

  describe('setSelectedDate', () => {
    it('should handle setSelectedDate with payload', () => {
      const mockDate = DateTime.fromISO('2021-01-01T00:00:00.000Z', {
        zone: 'utc',
      })
      const state = chartSlice.reducer(
        mockInitialChartState,
        setSelectedDate(mockDate)
      )
      expect(state).toEqual({
        ...mockInitialChartState,
        selectedDate: mockDate,
      })
    })
  })

  describe('setCurrentTimeStep', () => {
    it('should handle setCurrentTimeStep with payload', () => {
      const state = chartSlice.reducer(
        mockInitialChartState,
        setCurrentTimeStep(TimeStep.MONTH)
      )
      expect(state).toEqual({
        ...mockInitialChartState,
        currentTimeStep: TimeStep.MONTH,
      })
    })
    it('should disable showCompare if timestep is year', () => {
      const state = chartSlice.reducer(
        { ...mockInitialChartState, showCompare: true },
        setCurrentTimeStep(TimeStep.YEAR)
      )
      expect(state).toEqual({
        ...mockInitialChartState,
        showCompare: false,
        currentTimeStep: TimeStep.YEAR,
      })
    })
  })

  describe('setCurrentIndex', () => {
    it('should handle setCurrentIndex with payload', () => {
      const state = chartSlice.reducer(
        mockInitialChartState,
        setCurrentIndex(1)
      )
      expect(state).toEqual({
        ...mockInitialChartState,
        currentIndex: 1,
      })
    })
  })

  describe('setCurrentDataChart', () => {
    it('should handle setCurrentDataChart with payload', () => {
      const state = chartSlice.reducer(
        mockInitialChartState,
        setCurrentDataChart(graphData)
      )
      expect(state).toEqual({
        ...mockInitialChartState,
        currentDatachart: graphData,
      })
    })
  })

  describe('setCurrentDataChartIndex', () => {
    it('should handle setCurrentDataChartIndex with payload', () => {
      const state = chartSlice.reducer(
        mockInitialChartState,
        setCurrentDataChartIndex(1)
      )
      expect(state).toEqual({
        ...mockInitialChartState,
        currentDatachartIndex: 1,
      })
    })
  })

  describe('setLoading', () => {
    it('should handle setLoading with payload', () => {
      const state = chartSlice.reducer(mockInitialChartState, setLoading(false))
      expect(state).toEqual({
        ...mockInitialChartState,
        loading: false,
      })
    })
  })

  describe('setShowCompare', () => {
    it('should handle setShowCompare', () => {
      const state = chartSlice.reducer(
        mockInitialChartState,
        setShowCompare(true)
      )
      expect(state).toEqual({
        ...mockInitialChartState,
        showCompare: true,
      })
    })
  })
})

describe('chart reducer', () => {
  it('should return the initial state', () => {
    const initialState = chartSlice.reducer(undefined, { type: undefined })
    expect(initialState).toEqual(mockInitialChartState)
  })

  it('should return same state if no action', () => {
    const state = chartSlice.reducer(mockInitialChartState, { type: undefined })
    expect(state).toEqual(mockInitialChartState)
  })

  describe('setSelectedDate', () => {
    it('should handle SET_SELECTED_DATE with payload', () => {
      const mockDate = DateTime.fromISO('2021-01-01T00:00:00.000Z', {
        zone: 'utc',
      })
      const state = chartSlice.reducer(
        mockInitialChartState,
        setSelectedDate(mockDate)
      )
      expect(state).toEqual({
        ...mockInitialChartState,
        selectedDate: mockDate,
      })
    })
  })

  describe('setCurrentTimeStep', () => {
    it('should handle SET_CURRENT_TIMESTEP with payload', () => {
      const state = chartSlice.reducer(
        mockInitialChartState,
        setCurrentTimeStep(TimeStep.MONTH)
      )
      expect(state).toEqual({
        ...mockInitialChartState,
        currentTimeStep: TimeStep.MONTH,
      })
    })
  })

  describe('setCurrentIndex', () => {
    it('should handle SET_CURRENT_INDEX with payload', () => {
      const state = chartSlice.reducer(
        mockInitialChartState,
        setCurrentIndex(1)
      )
      expect(state).toEqual({
        ...mockInitialChartState,
        currentIndex: 1,
      })
    })
  })

  describe('setCurrentDataChart', () => {
    it('should handle SET_CURRENT_DATACHART with payload', () => {
      const state = chartSlice.reducer(
        mockInitialChartState,
        setCurrentDataChart(graphData)
      )
      expect(state).toEqual({
        ...mockInitialChartState,
        currentDatachart: graphData,
      })
    })
  })

  describe('setCurrentDataChartIndex', () => {
    it('should handle SET_CURRENT_DATACHART_INDEX with payload', () => {
      const state = chartSlice.reducer(
        mockInitialChartState,
        setCurrentDataChartIndex(1)
      )
      expect(state).toEqual({
        ...mockInitialChartState,
        currentDatachartIndex: 1,
      })
    })
  })

  describe('setLoading', () => {
    it('should handle SET_LOADING with payload', () => {
      const state = chartSlice.reducer(mockInitialChartState, setLoading(false))
      expect(state).toEqual({
        ...mockInitialChartState,
        loading: false,
      })
    })
  })
})
