import { FluidType } from 'enum/fluid.enum'
import { ScreenType } from 'enum/screen.enum'
import { FluidConnection, FluidStatus, TermsStatus } from 'models'
import { PartnersInfo } from 'models/partnersInfo.model'
import { Notes } from 'models/releaseNotes.model'
import { SgeStore } from 'models/sgeStore.model'
import { defaultAction } from 'store'

export const CHANGE_SCREEN_TYPE = 'CHANGE_SCREEN_TYPE'
export const SET_FLUID_STATUS = 'SET_FLUID_STATUS'
export const SET_PARTNERS_INFO = 'SET_PARTNERS_INFO'
export const SET_SHOULD_REFRESH_CONSENT = 'SET_SHOULD_REFRESH_CONSENT'
export const SHOW_RELEASE_NOTES = 'SHOW_RELEASE_NOTES'
export const TOGGLE_ANALYSIS_NOTIFICATION = 'TOGGLE_ANALYSIS_NOTIFICATION'
export const TOGGLE_CHALLENGE_ACTION_NOTIFICATION =
  'TOGGLE_CHALLENGE_ACTION_NOTIFICATION'
export const TOGGLE_CHALLENGE_DUEL_NOTIFICATION =
  'TOGGLE_CHALLENGE_DUEL_NOTIFICATION'
export const TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION =
  'TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION'
export const UPDATE_FLUID_CONNECTION = 'UPDATE_FLUID_CONNECTION'
export const UPDATE_SGE_CONNECT = 'UPDATE_SGE_CONNECT'
export const UPDATE_TERMS_VALIDATION = 'UPDATE_TERMS_VALIDATION'

interface ChangeScreenType {
  type: typeof CHANGE_SCREEN_TYPE
  payload?: ScreenType
}

interface SetPartnersInfo {
  type: typeof SET_PARTNERS_INFO
  payload?: PartnersInfo
}

interface SetPartnersInfo {
  type: typeof SET_PARTNERS_INFO
  payload?: PartnersInfo
}

interface ToggleChallengeExplorationNotification {
  type: typeof TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION
  payload?: boolean
}

interface ToggleChallengeActionNotification {
  type: typeof TOGGLE_CHALLENGE_ACTION_NOTIFICATION
  payload?: boolean
}

interface ToggleChallengeDuelNotification {
  type: typeof TOGGLE_CHALLENGE_DUEL_NOTIFICATION
  payload?: boolean
}

interface ToggleAnalysisNotification {
  type: typeof TOGGLE_ANALYSIS_NOTIFICATION
  payload?: boolean
}

interface SetFluidStatus {
  type: typeof SET_FLUID_STATUS
  payload?: FluidStatus[]
}

interface UpdatedFluidConnection {
  type: typeof UPDATE_FLUID_CONNECTION
  payload?: { fluidType: FluidType; fluidConnection: FluidConnection }
}

interface UpdateTermValidation {
  type: typeof UPDATE_TERMS_VALIDATION
  payload?: TermsStatus
}

interface ShowReleaseNotes {
  type: typeof SHOW_RELEASE_NOTES
  payload?: { show: boolean; notes: Notes[]; redirectLink?: string }
}

interface SetShouldRefreshConsent {
  type: typeof SET_SHOULD_REFRESH_CONSENT
  payload?: boolean
}
interface UpdateSGEConnect {
  type: typeof UPDATE_SGE_CONNECT
  payload?: SgeStore
}

export function changeScreenType(screenType: ScreenType): ChangeScreenType {
  return {
    type: CHANGE_SCREEN_TYPE,
    payload: screenType,
  }
}

export function showReleaseNotes(
  show: boolean,
  notes: Notes[],
  redirectLink?: string
): ShowReleaseNotes {
  return {
    type: SHOW_RELEASE_NOTES,
    payload: { show, notes, redirectLink },
  }
}

export function toggleChallengeExplorationNotification(
  notification: boolean
): ToggleChallengeExplorationNotification {
  return {
    type: TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION,
    payload: notification,
  }
}

export function toggleChallengeActionNotification(
  notification: boolean
): ToggleChallengeActionNotification {
  return {
    type: TOGGLE_CHALLENGE_ACTION_NOTIFICATION,
    payload: notification,
  }
}

export function toggleChallengeDuelNotification(
  notification: boolean
): ToggleChallengeDuelNotification {
  return {
    type: TOGGLE_CHALLENGE_DUEL_NOTIFICATION,
    payload: notification,
  }
}

export function toggleAnalysisNotification(
  notification: boolean
): ToggleAnalysisNotification {
  return {
    type: TOGGLE_ANALYSIS_NOTIFICATION,
    payload: notification,
  }
}

export function setFluidStatus(fluidStatus: FluidStatus[]): SetFluidStatus {
  return {
    type: SET_FLUID_STATUS,
    payload: fluidStatus,
  }
}
export function updatedFluidConnection(
  fluidType: FluidType,
  fluidConnection: FluidConnection
): UpdatedFluidConnection {
  return {
    type: UPDATE_FLUID_CONNECTION,
    payload: { fluidType, fluidConnection },
  }
}

export function updateTermValidation(
  termsStatus: TermsStatus
): UpdateTermValidation {
  return {
    type: UPDATE_TERMS_VALIDATION,
    payload: termsStatus,
  }
}

export function setPartnersInfo(partnersInfo: PartnersInfo): SetPartnersInfo {
  return {
    type: SET_PARTNERS_INFO,
    payload: partnersInfo,
  }
}

export function setShouldRefreshConsent(
  shouldRefreshConsent: boolean
): SetShouldRefreshConsent {
  return {
    type: SET_SHOULD_REFRESH_CONSENT,
    payload: shouldRefreshConsent,
  }
}

export function updateSgeStore(sgeStore: SgeStore): UpdateSGEConnect {
  return {
    type: UPDATE_SGE_CONNECT,
    payload: sgeStore,
  }
}

export type GlobalActionTypes =
  | ChangeScreenType
  | ToggleChallengeExplorationNotification
  | ToggleChallengeActionNotification
  | ToggleChallengeDuelNotification
  | ToggleAnalysisNotification
  | SetFluidStatus
  | UpdatedFluidConnection
  | UpdateTermValidation
  | ShowReleaseNotes
  | SetShouldRefreshConsent
  | UpdateSGEConnect
  | SetPartnersInfo
  | typeof defaultAction
