import { mockProfileEcogesture } from '../../../tests/__mocks__/profileEcogesture.mock'
import { createMockEcolyoStore } from '../../../tests/__mocks__/store'
import {
  updateProfileEcogesture,
  UPDATE_PROFILE_ECOGESTURE,
} from './profileEcogesture.actions'

const mockUpdateProfileEcogesture = jest.fn()
const mockNewProfileEcogestureEntry = jest.fn()
jest.mock('services/profileEcogesture.service', () => {
  return jest.fn(() => {
    return {
      updateProfileEcogesture: mockUpdateProfileEcogesture,
      newProfileEcogestureEntry: mockNewProfileEcogestureEntry,
    }
  })
})

describe('profileEcogesture actions', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    store.clearActions()
  })
  it('should create an UPDATE_PROFILE_ECOGESTURE action when ecogestureProfile is updated', async () => {
    mockUpdateProfileEcogesture.mockResolvedValueOnce(mockProfileEcogesture)
    const expectedActions = [
      {
        type: UPDATE_PROFILE_ECOGESTURE,
        payload: mockProfileEcogesture,
      },
    ]
    await store.dispatch(updateProfileEcogesture(mockProfileEcogesture))
    expect(store.getActions()).toEqual(expectedActions)
  })

  it('should not create action when ProfileEcogesture is not updated', async () => {
    mockUpdateProfileEcogesture.mockResolvedValueOnce(null)
    await store.dispatch(updateProfileEcogesture(mockProfileEcogesture))
    expect(store.getActions()).toEqual([])
  })
})
